==> ws-v3.50.4-src.tar.gz: ws-v3.50-4/src/sheet/Japanese-utf8.cpp <==
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","","");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Row Counter", "行数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Column Counter", "列数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Row Counter", "固定行数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Column Counter","固定列数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Grid Line Type","グリッドラインの種類");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Width","セルの幅（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Height","可変セルの高さ（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Height","固定セルの高さ（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Font No.","可変セルのフォント（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Default Font No.","固定セルのフォント");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Edit Enabled", "編集可");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Horizontal number drawing","セルの列番号表示");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Vertical number drawing","セルの行番号表示");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Sheet Back Color","シートの背景色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Back Color","可変セルの背景色（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Text Color","可変セルの文字色（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Back Color","固定セルの背景色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Text Color","固定セルの文字色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Grid Color","グリッドの色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Select Item","データベース項目");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort Item1","ソート項目１");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort1","ソート条件１");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort Item2","ソート項目２");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort2","ソート条件２");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort Item3","ソート項目３");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort3","ソート条件３");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Select SQL","SQL文");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR ASC","昇順");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR DESC","降順");

  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR None","なし");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR Horz","水平");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR Vert","垂直");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR Both","両方");

==> ws-v3.70.5-src.tar.gz: ws-v3.70-5/src/sheet/Japanese-utf8.cpp <==
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","","");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Row Counter", "行数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Column Counter", "列数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Row Counter", "固定行数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Column Counter","固定列数");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Grid Line Type","グリッドラインの種類");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Width","セルの幅（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Height","可変セルの高さ（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Height","固定セルの高さ（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Font No.","可変セルのフォント（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Default Font No.","固定セルのフォント");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Edit Enabled", "編集可");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Horizontal number drawing","セルの列番号表示");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Vertical number drawing","セルの行番号表示");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Sheet Back Color","シートの背景色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Back Color","可変セルの背景色（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Cell Default Text Color","可変セルの文字色（規定値）");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Back Color","固定セルの背景色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Fixed Cell Text Color","固定セルの文字色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR Grid Color","グリッドの色");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Select Item","データベース項目");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort Item1","ソート項目１");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort1","ソート条件１");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort Item2","ソート項目２");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort2","ソート条件２");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort Item3","ソート項目３");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Sort3","ソート条件３");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Select SQL","SQL文");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR ASC","昇順");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR DESC","降順");

  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR None","なし");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR Horz","水平");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR Vert","垂直");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X:WSSTR Both","両方");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Cell Auto Resize","データベース接続時にセルの自動調整");
  WSGIappLocaleSet()->setLocaleString("UTF8_JP","p1:WSSTR DB Cell Title","データベース接続時にセルのタイトルを自動表示");
